@@ -6,8 +6,11 @@
  *
  */
 
+#include <cstdlib>
 #include <gtkmm.h>
 
+using std::strtod;
+
 class CellItem_Product
 {
 public:
@@ -196,16 +199,19 @@ void Example_TreeView_EditableCells::on_column_number_edited(const Glib::ustring
 
   //Get the row from the path:
   Glib::RefPtr<Gtk::TreeModel> refModel = m_TreeView._get_base_model();
-  Gtk::TreeModel::iterator iter = refModel->get_iter(path);
-  if(iter)
-  {  
-    //Convert the text to a number, using the same logic used by GtkCellRendererText when it stores numbers.
-    char* pchEnd = 0;
-    int new_value = (int) strtod(new_text.c_str(), &pchEnd);
-
-    //Store the user's new text in the model:
-    Gtk::TreeRow row = *iter;
-    row[m_columns.number] = new_value;
+  if(refModel)
+  {
+    Gtk::TreeModel::iterator iter = refModel->get_iter(path);
+    if(iter)
+    {
+      //Convert the text to a number, using the same logic used by GtkCellRendererText when it stores numbers.
+      char* pchEnd = 0;
+      int new_value = (int) strtod(new_text.c_str(), &pchEnd);
+  
+      //Store the user's new text in the model:
+      Gtk::TreeRow row = *iter;
+      row[m_columns.number] = new_value;
+    }
   }
 }
 
@@ -215,12 +221,15 @@ void Example_TreeView_EditableCells::on_column_product_edited(const Glib::ustrin
 
   //Get the row from the path:
   Glib::RefPtr<Gtk::TreeModel> refModel = m_TreeView._get_base_model();
-  Gtk::TreeModel::iterator iter = refModel->get_iter(path);
-  if(iter)
+  if(refModel)
   {
-      //Store the user's new text in the model:
-      Gtk::TreeRow row = *iter;
-      row[m_columns.product] = new_text;
+    Gtk::TreeModel::iterator iter = refModel->get_iter(path);
+    if(iter)
+    {
+        //Store the user's new text in the model:
+        Gtk::TreeRow row = *iter;
+        row[m_columns.product] = new_text;
+    }
   }
 }
 
@@ -243,7 +252,11 @@ void Example_TreeView_EditableCells::add_columns()
     if(pCellRenderText)
     {
       //Set the appropriate property,
+#ifdef GLIBMM_PROPERTIES_ENABLED
       pCellRenderText->property_editable() = true;
+#else
+      pCellRenderText->set_property("editable", true);
+#endif
     
       //Connect to the appropriate signal, sending the model_column too,
       pCellRenderText->signal_edited().connect( sigc::mem_fun(*this, &Example_TreeView_EditableCells::on_column_number_edited) );
@@ -261,7 +274,11 @@ void Example_TreeView_EditableCells::add_columns()
     if(pCellRenderText)
     {
       //Set the appropriate property,
+      #ifdef GLIBMM_PROPERTIES_ENABLED
       pCellRenderText->property_editable() = true;
+      #else
+      pCellRenderText->set_property("editable", true);
+      #endif
     
       //Connect to the appropriate signal, sending the model_column too,
       pCellRenderText->signal_edited().connect( sigc::mem_fun(*this, &Example_TreeView_EditableCells::on_column_product_edited) );
